@@ -1,13 +1,15 @@
-from collections.abc import Sequence
-from typing import ClassVar, TypeAlias
+"""The item module holds the GridSortItem and related types."""
+from typing import Optional
 
-from pydantic import Field
+from pydantic import Field as PyField
+from typing_extensions import TypeAlias
 
 from mui.v5.grid.base import GridBaseModel
-from mui.v5.grid.sort.direction import GridSortDirection
+from mui.v5.grid.sort.direction import GridSortDirection, GridSortDirectionLiterals
 
-_Field: TypeAlias = str
-_Sort: TypeAlias = GridSortDirection | None
+Field: TypeAlias = str
+Sort: TypeAlias = Optional[GridSortDirection]
+SortLiterals: TypeAlias = Optional[GridSortDirectionLiterals]
 
 
 class GridSortItem(GridBaseModel):
@@ -24,16 +26,14 @@ class GridSortItem(GridBaseModel):
         sort (GridSortDirection): The direction of the column that the grid should sort.
     """
 
-    field: _Field = Field(
+    field: Field = PyField(
         default=...,
         title="Field",
         description="The direction of the column that the grid should sort.",
     )
 
-    sort: _Sort = Field(
+    sort: Sort = PyField(
         default=...,
         title="Sort",
         description="The direction of the column that the grid should sort.",
     )
-
-    _optional_keys: ClassVar[set[Sequence[str]]] = set()
